@@ -315,6 +315,18 @@ func (t *Telegraf) runAgent(ctx context.Context, c *config.Config, reloadConfig
 		log.Printf("W! Deprecated secretstores: %d and %d options", count[0], count[1])
 	}
 
+	// Compute the amount of locked memory needed for the secrets
+	required := 2 * c.NumberSecrets * uint64(os.Getpagesize())
+	available := getLockedMemoryLimit()
+	if required > available {
+		required /= 1024
+		available /= 1024
+		log.Printf("I! Found %d secrets...", c.NumberSecrets)
+		msg := fmt.Sprintf("Insufficient lockable memory %dkb when %dkb is required.", available, required)
+		msg += " Please increase the limit for Telegraf in your Operating System!"
+		log.Printf("W! " + color.RedString(msg))
+	}
+
 	ag := agent.NewAgent(c)
 
 	// Notify systemd that telegraf is ready
