@@ -194,8 +194,7 @@ func TestServeHTTP(t *testing.T) {
 			defer wg.Done()
 			for m := range d {
 				ro.AddMetric(m)
-				//nolint:errcheck,revive // test will fail anyway if the write fails
-				ro.Write()
+				ro.Write() //nolint:errcheck // test will fail anyway if the write fails
 			}
 		}(dst)
 
