@@ -10,8 +10,9 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/influxdata/telegraf/testutil"
 	"github.com/stretchr/testify/require"
+
+	"github.com/influxdata/telegraf/testutil"
 )
 
 var masterMetrics map[string]interface{}
@@ -287,9 +288,7 @@ func TestMain(m *testing.M) {
 	masterRouter.HandleFunc("/metrics/snapshot", func(w http.ResponseWriter, r *http.Request) {
 		w.WriteHeader(http.StatusOK)
 		w.Header().Set("Content-Type", "application/json")
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		json.NewEncoder(w).Encode(masterMetrics)
+		json.NewEncoder(w).Encode(masterMetrics) //nolint:errcheck // ignore the returned error as we cannot do anything about it anyway
 	})
 	masterTestServer = httptest.NewServer(masterRouter)
 
@@ -297,9 +296,7 @@ func TestMain(m *testing.M) {
 	slaveRouter.HandleFunc("/metrics/snapshot", func(w http.ResponseWriter, r *http.Request) {
 		w.WriteHeader(http.StatusOK)
 		w.Header().Set("Content-Type", "application/json")
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		json.NewEncoder(w).Encode(slaveMetrics)
+		json.NewEncoder(w).Encode(slaveMetrics) //nolint:errcheck // ignore the returned error as we cannot do anything about it anyway
 	})
 	slaveTestServer = httptest.NewServer(slaveRouter)
 
@@ -340,7 +337,7 @@ func TestMasterFilter(t *testing.T) {
 
 	// Assert expected metrics are present.
 	for _, v := range m.MasterCols {
-		for _, x := range getMetrics(MASTER, v) {
+		for _, x := range m.getMetrics(MASTER, v) {
 			_, ok := masterMetrics[x]
 			require.Truef(t, ok, "Didn't find key %s, it should present.", x)
 		}
@@ -357,7 +354,7 @@ func TestMasterFilter(t *testing.T) {
 
 	// Assert unexpected metrics are not present.
 	for _, v := range b {
-		for _, x := range getMetrics(MASTER, v) {
+		for _, x := range m.getMetrics(MASTER, v) {
 			_, ok := masterMetrics[x]
 			require.Falsef(t, ok, "Found key %s, it should be gone.", x)
 		}
@@ -402,13 +399,13 @@ func TestSlaveFilter(t *testing.T) {
 	m.filterMetrics(SLAVE, &slaveMetrics)
 
 	for _, v := range b {
-		for _, x := range getMetrics(SLAVE, v) {
+		for _, x := range m.getMetrics(SLAVE, v) {
 			_, ok := slaveMetrics[x]
 			require.Falsef(t, ok, "Found key %s, it should be gone.", x)
 		}
 	}
 	for _, v := range m.MasterCols {
-		for _, x := range getMetrics(SLAVE, v) {
+		for _, x := range m.getMetrics(SLAVE, v) {
 			_, ok := slaveMetrics[x]
 			require.Truef(t, ok, "Didn't find key %s, it should present.", x)
 		}
