@@ -35,6 +35,9 @@ func (n *NginxPlusAPI) gatherMetrics(addr *url.URL, acc telegraf.Accumulator) {
 		addError(acc, n.gatherHTTPLocationZonesMetrics(addr, acc))
 		addError(acc, n.gatherResolverZonesMetrics(addr, acc))
 	}
+	if n.APIVersion >= 6 {
+		addError(acc, n.gatherHTTPLimitReqsMetrics(addr, acc))
+	}
 }
 
 func addError(acc telegraf.Accumulator, err error) {
@@ -44,7 +47,7 @@ func addError(acc telegraf.Accumulator, err error) {
 	//
 	// The correct solution is to do a GET to /api to get the available paths
 	// on the server rather than simply ignore.
-	if err != errNotFound {
+	if !errors.Is(err, errNotFound) {
 		acc.AddError(err)
 	}
 }
@@ -54,7 +57,7 @@ func (n *NginxPlusAPI) gatherURL(addr *url.URL, path string) ([]byte, error) {
 	resp, err := n.client.Get(address)
 
 	if err != nil {
-		return nil, fmt.Errorf("error making HTTP request to %s: %s", address, err)
+		return nil, fmt.Errorf("error making HTTP request to %q: %w", address, err)
 	}
 	defer resp.Body.Close()
 
@@ -613,6 +616,43 @@ func (n *NginxPlusAPI) gatherStreamUpstreamsMetrics(addr *url.URL, acc telegraf.
 	return nil
 }
 
+// Added in 6 API version
+func (n *NginxPlusAPI) gatherHTTPLimitReqsMetrics(addr *url.URL, acc telegraf.Accumulator) error {
+	body, err := n.gatherURL(addr, httpLimitReqsPath)
+	if err != nil {
+		return err
+	}
+
+	var httpLimitReqs HTTPLimitReqs
+
+	if err := json.Unmarshal(body, &httpLimitReqs); err != nil {
+		return err
+	}
+
+	tags := getTags(addr)
+
+	for limitReqName, limit := range httpLimitReqs {
+		limitReqsTags := map[string]string{}
+		for k, v := range tags {
+			limitReqsTags[k] = v
+		}
+		limitReqsTags["limit"] = limitReqName
+		acc.AddFields(
+			"nginx_plus_api_http_limit_reqs",
+			map[string]interface{}{
+				"passed":           limit.Passed,
+				"delayed":          limit.Delayed,
+				"rejected":         limit.Rejected,
+				"delayed_dry_run":  limit.DelayedDryRun,
+				"rejected_dry_run": limit.RejectedDryRun,
+			},
+			limitReqsTags,
+		)
+	}
+
+	return nil
+}
+
 func getTags(addr *url.URL) map[string]string {
 	h := addr.Host
 	host, port, err := net.SplitHostPort(h)
