@@ -8,7 +8,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf/testutil"
@@ -35,8 +34,6 @@ func fakePassengerStatus(stat string) (string, error) {
 }
 
 func teardown(tempFilePath string) {
-	// Ignore the returned error as we want to remove the file and ignore missing file errors
-	//nolint:errcheck,revive
 	os.Remove(tempFilePath)
 }
 
@@ -49,7 +46,7 @@ func Test_Invalid_Passenger_Status_Cli(t *testing.T) {
 
 	err := r.Gather(&acc)
 	require.Error(t, err)
-	assert.Contains(t, err.Error(), `exec: "an-invalid-command": executable file not found in `)
+	require.Contains(t, err.Error(), `exec: "an-invalid-command": executable file not found in `)
 }
 
 func Test_Invalid_Xml(t *testing.T) {
@@ -65,7 +62,7 @@ func Test_Invalid_Xml(t *testing.T) {
 
 	err = r.Gather(&acc)
 	require.Error(t, err)
-	assert.Equal(t, "cannot parse input with error: EOF", err.Error())
+	require.Equal(t, "cannot parse input with error: EOF", err.Error())
 }
 
 // We test this by ensure that the error message match the path of default cli
@@ -80,7 +77,7 @@ func Test_Default_Config_Load_Default_Command(t *testing.T) {
 
 	err = r.Gather(&acc)
 	require.Error(t, err)
-	assert.Contains(t, err.Error(), "exec: \"passenger-status\": executable file not found in ")
+	require.Contains(t, err.Error(), "exec: \"passenger-status\": executable file not found in ")
 }
 
 func TestPassengerGenerateMetric(t *testing.T) {
