@@ -2,6 +2,7 @@ package execd
 
 import (
 	"bufio"
+	"errors"
 	"flag"
 	"fmt"
 	"io"
@@ -24,8 +25,7 @@ import (
 var now = time.Date(2020, 6, 30, 16, 16, 0, 0, time.UTC)
 
 func TestExternalOutputWorks(t *testing.T) {
-	influxSerializer, err := serializers.NewInfluxSerializer()
-	require.NoError(t, err)
+	influxSerializer := serializers.NewInfluxSerializer()
 
 	exe, err := os.Executable()
 	require.NoError(t, err)
@@ -71,8 +71,7 @@ func TestExternalOutputWorks(t *testing.T) {
 }
 
 func TestPartiallyUnserializableThrowError(t *testing.T) {
-	influxSerializer, err := serializers.NewInfluxSerializer()
-	require.NoError(t, err)
+	influxSerializer := serializers.NewInfluxSerializer()
 
 	exe, err := os.Executable()
 	require.NoError(t, err)
@@ -108,8 +107,7 @@ func TestPartiallyUnserializableThrowError(t *testing.T) {
 }
 
 func TestPartiallyUnserializableCanBeSkipped(t *testing.T) {
-	influxSerializer, err := serializers.NewInfluxSerializer()
-	require.NoError(t, err)
+	influxSerializer := serializers.NewInfluxSerializer()
 
 	exe, err := os.Executable()
 	require.NoError(t, err)
@@ -165,16 +163,15 @@ func runOutputConsumerProgram() {
 	for {
 		m, err := parser.Next()
 		if err != nil {
-			if err == influx.EOF {
+			if errors.Is(err, influx.EOF) {
 				return // stream ended
 			}
-			if parseErr, isParseError := err.(*influx.ParseError); isParseError {
-				//nolint:errcheck,revive // Test will fail anyway
+			var parseErr *influx.ParseError
+			if errors.As(err, &parseErr) {
 				fmt.Fprintf(os.Stderr, "parse ERR %v\n", parseErr)
 				//nolint:revive // error code is important for this "test"
 				os.Exit(1)
 			}
-			//nolint:errcheck,revive // Test will fail anyway
 			fmt.Fprintf(os.Stderr, "ERR %v\n", err)
 			//nolint:revive // error code is important for this "test"
 			os.Exit(1)
@@ -187,7 +184,6 @@ func runOutputConsumerProgram() {
 		)
 
 		if !testutil.MetricEqual(expected, m) {
-			//nolint:errcheck,revive // Test will fail anyway
 			fmt.Fprintf(os.Stderr, "metric doesn't match expected\n")
 			//nolint:revive // error code is important for this "test"
 			os.Exit(1)
