@@ -1,44 +1,60 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package sql
 
 import (
 	gosql "database/sql"
+	_ "embed"
 	"fmt"
 	"strings"
+	"time"
 
 	//Register sql drivers
-	_ "github.com/denisenkom/go-mssqldb"   // mssql (sql server)
-	_ "github.com/go-sql-driver/mysql"     // mysql
-	_ "github.com/jackc/pgx/v4/stdlib"     // pgx (postgres)
-	_ "github.com/snowflakedb/gosnowflake" // snowflake
+	_ "github.com/ClickHouse/clickhouse-go" // clickhouse
+	_ "github.com/denisenkom/go-mssqldb"    // mssql (sql server)
+	_ "github.com/go-sql-driver/mysql"      // mysql
+	_ "github.com/jackc/pgx/v4/stdlib"      // pgx (postgres)
+	_ "github.com/snowflakedb/gosnowflake"  // snowflake
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/outputs"
 )
 
+//go:embed sample.conf
+var sampleConfig string
+
 type ConvertStruct struct {
-	Integer      string
-	Real         string
-	Text         string
-	Timestamp    string
-	Defaultvalue string
-	Unsigned     string
-	Bool         string
+	Integer         string
+	Real            string
+	Text            string
+	Timestamp       string
+	Defaultvalue    string
+	Unsigned        string
+	Bool            string
+	ConversionStyle string
 }
 
 type SQL struct {
-	Driver              string
-	DataSourceName      string
-	TimestampColumn     string
-	TableTemplate       string
-	TableExistsTemplate string
-	InitSQL             string `toml:"init_sql"`
-	Convert             ConvertStruct
+	Driver                string
+	DataSourceName        string
+	TimestampColumn       string
+	TableTemplate         string
+	TableExistsTemplate   string
+	InitSQL               string `toml:"init_sql"`
+	Convert               ConvertStruct
+	ConnectionMaxIdleTime time.Duration
+	ConnectionMaxLifetime time.Duration
+	ConnectionMaxIdle     int
+	ConnectionMaxOpen     int
 
 	db     *gosql.DB
 	Log    telegraf.Logger `toml:"-"`
 	tables map[string]bool
 }
 
+func (*SQL) SampleConfig() string {
+	return sampleConfig
+}
+
 func (p *SQL) Connect() error {
 	db, err := gosql.Open(p.Driver, p.DataSourceName)
 	if err != nil {
@@ -50,6 +66,11 @@ func (p *SQL) Connect() error {
 		return err
 	}
 
+	db.SetConnMaxIdleTime(p.ConnectionMaxIdleTime)
+	db.SetConnMaxLifetime(p.ConnectionMaxLifetime)
+	db.SetMaxIdleConns(p.ConnectionMaxIdle)
+	db.SetMaxOpenConns(p.ConnectionMaxOpen)
+
 	if p.InitSQL != "" {
 		_, err = db.Exec(p.InitSQL)
 		if err != nil {
@@ -69,12 +90,12 @@ func (p *SQL) Close() error {
 
 // Quote an identifier (table or column name)
 func quoteIdent(name string) string {
-	return `"` + strings.Replace(sanitizeQuoted(name), `"`, `""`, -1) + `"`
+	return `"` + strings.ReplaceAll(sanitizeQuoted(name), `"`, `""`) + `"`
 }
 
 // Quote a string literal
 func quoteStr(name string) string {
-	return "'" + strings.Replace(name, "'", "''", -1) + "'"
+	return "'" + strings.ReplaceAll(name, "'", "''") + "'"
 }
 
 func sanitizeQuoted(in string) string {
@@ -99,7 +120,13 @@ func (p *SQL) deriveDatatype(value interface{}) string {
 	case int64:
 		datatype = p.Convert.Integer
 	case uint64:
-		datatype = fmt.Sprintf("%s %s", p.Convert.Integer, p.Convert.Unsigned)
+		if p.Convert.ConversionStyle == "unsigned_suffix" {
+			datatype = fmt.Sprintf("%s %s", p.Convert.Integer, p.Convert.Unsigned)
+		} else if p.Convert.ConversionStyle == "literal" {
+			datatype = p.Convert.Unsigned
+		} else {
+			p.Log.Errorf("unknown converstaion style: %s", p.Convert.ConversionStyle)
+		}
 	case float64:
 		datatype = p.Convert.Real
 	case string:
@@ -113,50 +140,8 @@ func (p *SQL) deriveDatatype(value interface{}) string {
 	return datatype
 }
 
-var sampleConfig = `
-  ## Database driver
-  ## Valid options: mssql (Microsoft SQL Server), mysql (MySQL), pgx (Postgres),
-  ##  sqlite (SQLite3), snowflake (snowflake.com)
-  # driver = ""
-
-  ## Data source name
-  ## The format of the data source name is different for each database driver.
-  ## See the plugin readme for details.
-  # data_source_name = ""
-
-  ## Timestamp column name
-  # timestamp_column = "timestamp"
-
-  ## Table creation template
-  ## Available template variables:
-  ##  {TABLE} - table name as a quoted identifier
-  ##  {TABLELITERAL} - table name as a quoted string literal
-  ##  {COLUMNS} - column definitions (list of quoted identifiers and types)
-  # table_template = "CREATE TABLE {TABLE}({COLUMNS})"
-
-  ## Table existence check template
-  ## Available template variables:
-  ##  {TABLE} - tablename as a quoted identifier
-  # table_exists_template = "SELECT 1 FROM {TABLE} LIMIT 1"
-
-  ## Initialization SQL
-  # init_sql = ""
-
-  ## Metric type to SQL type conversion
-  #[outputs.sql.convert]
-  #  integer              = "INT"
-  #  real                 = "DOUBLE"
-  #  text                 = "TEXT"
-  #  timestamp            = "TIMESTAMP"
-  #  defaultvalue         = "TEXT"
-  #  unsigned             = "UNSIGNED"
-`
-
-func (p *SQL) SampleConfig() string { return sampleConfig }
-func (p *SQL) Description() string  { return "Send metrics to SQL Database" }
-
 func (p *SQL) generateCreateTable(metric telegraf.Metric) string {
-	var columns []string
+	columns := make([]string, 0, len(metric.TagList())+len(metric.FieldList())+1)
 	//  ##  {KEY_COLUMNS} is a comma-separated list of key columns (timestamp and tags)
 	//var pk []string
 
@@ -177,16 +162,17 @@ func (p *SQL) generateCreateTable(metric telegraf.Metric) string {
 	}
 
 	query := p.TableTemplate
-	query = strings.Replace(query, "{TABLE}", quoteIdent(metric.Name()), -1)
-	query = strings.Replace(query, "{TABLELITERAL}", quoteStr(metric.Name()), -1)
-	query = strings.Replace(query, "{COLUMNS}", strings.Join(columns, ","), -1)
-	//query = strings.Replace(query, "{KEY_COLUMNS}", strings.Join(pk, ","), -1)
+	query = strings.ReplaceAll(query, "{TABLE}", quoteIdent(metric.Name()))
+	query = strings.ReplaceAll(query, "{TABLELITERAL}", quoteStr(metric.Name()))
+	query = strings.ReplaceAll(query, "{COLUMNS}", strings.Join(columns, ","))
+	//query = strings.ReplaceAll(query, "{KEY_COLUMNS}", strings.Join(pk, ","))
 
 	return query
 }
 
 func (p *SQL) generateInsert(tablename string, columns []string) string {
-	var placeholders, quotedColumns []string
+	placeholders := make([]string, 0, len(columns))
+	quotedColumns := make([]string, 0, len(columns))
 	for _, column := range columns {
 		quotedColumns = append(quotedColumns, quoteIdent(column))
 	}
@@ -209,13 +195,15 @@ func (p *SQL) generateInsert(tablename string, columns []string) string {
 }
 
 func (p *SQL) tableExists(tableName string) bool {
-	stmt := strings.Replace(p.TableExistsTemplate, "{TABLE}", quoteIdent(tableName), -1)
+	stmt := strings.ReplaceAll(p.TableExistsTemplate, "{TABLE}", quoteIdent(tableName))
 
 	_, err := p.db.Exec(stmt)
 	return err == nil
 }
 
 func (p *SQL) Write(metrics []telegraf.Metric) error {
+	var err error
+
 	for _, metric := range metrics {
 		tablename := metric.Name()
 
@@ -226,8 +214,8 @@ func (p *SQL) Write(metrics []telegraf.Metric) error {
 			if err != nil {
 				return err
 			}
-			p.tables[tablename] = true
 		}
+		p.tables[tablename] = true
 
 		var columns []string
 		var values []interface{}
@@ -248,12 +236,33 @@ func (p *SQL) Write(metrics []telegraf.Metric) error {
 		}
 
 		sql := p.generateInsert(tablename, columns)
-		_, err := p.db.Exec(sql, values...)
 
-		if err != nil {
-			// check if insert error was caused by column mismatch
-			p.Log.Errorf("Error during insert: %v, %v", err, sql)
-			return err
+		switch p.Driver {
+		case "clickhouse":
+			// ClickHouse needs to batch inserts with prepared statements
+			tx, err := p.db.Begin()
+			if err != nil {
+				return fmt.Errorf("begin failed: %w", err)
+			}
+			stmt, err := tx.Prepare(sql)
+			if err != nil {
+				return fmt.Errorf("prepare failed: %w", err)
+			}
+			defer stmt.Close() //nolint:revive // We cannot do anything about a failing close.
+
+			_, err = stmt.Exec(values...)
+			if err != nil {
+				return fmt.Errorf("execution failed: %w", err)
+			}
+			err = tx.Commit()
+			if err != nil {
+				return fmt.Errorf("commit failed: %w", err)
+			}
+		default:
+			_, err = p.db.Exec(sql, values...)
+			if err != nil {
+				return fmt.Errorf("execution failed: %w", err)
+			}
 		}
 	}
 	return nil
@@ -269,13 +278,20 @@ func newSQL() *SQL {
 		TableExistsTemplate: "SELECT 1 FROM {TABLE} LIMIT 1",
 		TimestampColumn:     "timestamp",
 		Convert: ConvertStruct{
-			Integer:      "INT",
-			Real:         "DOUBLE",
-			Text:         "TEXT",
-			Timestamp:    "TIMESTAMP",
-			Defaultvalue: "TEXT",
-			Unsigned:     "UNSIGNED",
-			Bool:         "BOOL",
+			Integer:         "INT",
+			Real:            "DOUBLE",
+			Text:            "TEXT",
+			Timestamp:       "TIMESTAMP",
+			Defaultvalue:    "TEXT",
+			Unsigned:        "UNSIGNED",
+			Bool:            "BOOL",
+			ConversionStyle: "unsigned_suffix",
 		},
+		// Defaults for the connection settings (ConnectionMaxIdleTime,
+		// ConnectionMaxLifetime, ConnectionMaxIdle, and ConnectionMaxOpen)
+		// mirror the golang defaults. As of go 1.18 all of them default to 0
+		// except max idle connections which is 2. See
+		// https://pkg.go.dev/database/sql#DB.SetMaxIdleConns
+		ConnectionMaxIdle: 2,
 	}
 }
