@@ -41,10 +41,9 @@ func pwgen(n int) string {
 	charset := []byte("abcdedfghijklmnopqrstABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789")
 
 	nchars := len(charset)
-	buffer := make([]byte, n)
-
-	for i := range buffer {
-		buffer[i] = charset[rand.Intn(nchars)]
+	buffer := make([]byte, 0, n)
+	for i := 0; i < n; i++ {
+		buffer = append(buffer, charset[rand.Intn(nchars)])
 	}
 
 	return string(buffer)
@@ -191,9 +190,7 @@ func TestMysqlIntegration(t *testing.T) {
 	}
 	err = container.Start()
 	require.NoError(t, err, "failed to start container")
-	defer func() {
-		require.NoError(t, container.Terminate(), "terminating container failed")
-	}()
+	defer container.Terminate()
 
 	//use the plugin to write to the database
 	address := fmt.Sprintf("%v:%v@tcp(%v:%v)/%v",
@@ -278,9 +275,7 @@ func TestPostgresIntegration(t *testing.T) {
 	}
 	err = container.Start()
 	require.NoError(t, err, "failed to start container")
-	defer func() {
-		require.NoError(t, container.Terminate(), "terminating container failed")
-	}()
+	defer container.Terminate()
 
 	//use the plugin to write to the database
 	// host, port, username, password, dbname
@@ -364,9 +359,7 @@ func TestClickHouseIntegration(t *testing.T) {
 	}
 	err = container.Start()
 	require.NoError(t, err, "failed to start container")
-	defer func() {
-		require.NoError(t, container.Terminate(), "terminating container failed")
-	}()
+	defer container.Terminate()
 
 	//use the plugin to write to the database
 	// host, port, username, password, dbname
